@@ -1,9 +1,5 @@
 //! Import the prelude to gain convenient access to helper traits
 pub use crate::eic::pin::EicPin;
-#[allow(deprecated)]
-pub use crate::gpio::v1::GpioExt as _atsamd21_hal_gpio_GpioExt;
-#[allow(deprecated)]
-pub use crate::spi_common::CommonSpi as _atsamd_hal_spi_common_CommonSpi;
 pub use crate::time::U32Ext as _atsamd21_hal_time_U32Ext;
 pub use crate::timer_traits::InterruptDrivenTimer as _atsamd_hal_timer_traits_InterruptDrivenTimer;
 
