@@ -1,6 +1,9 @@
 //! USB Device support
 
-use crate::gpio;
+use crate::gpio::{
+    pin::{Pin, PA23, PA24, PA25},
+    AlternateG,
+};
 
 pub use usb_device;
 
@@ -11,10 +14,10 @@ mod devicedesc;
 use self::devicedesc::Descriptors;
 
 /// Emit SOF at 1Khz on this pin when configured as function G
-pub type SofPad = gpio::Pa23<gpio::PfG>;
+pub type SofPad = Pin<PA23, AlternateG>;
 
 /// USB D- is connected here
-pub type DmPad = gpio::Pa24<gpio::PfG>;
+pub type DmPad = Pin<PA24, AlternateG>;
 
 /// USB D+ is connected here
-pub type DpPad = gpio::Pa25<gpio::PfG>;
+pub type DpPad = Pin<PA25, AlternateG>;
