@@ -379,7 +379,6 @@
 //! message_region3_sha256[6] = 0xDEAD_BEEF;
 //!
 //! icm.enable()
-use crate::pac::generic::Variant;
 use crate::pac::icm::uasr::URAT_A;
 
 use paste::paste;
@@ -472,6 +471,7 @@ bitfield::bitfield! {
     /// all the regions or via the `bitmask` argument
     /// narrow it down to the specific set of [`RegionNum`]
     /// of interest.
+    #[derive(Default)]
     pub struct Interrupt(u32);
     impl Debug;
     u8;
@@ -521,11 +521,6 @@ impl Interrupt {
         RegionHashCompleted::from_bits_truncate(self.get_rhc())
     }
 }
-impl Default for Interrupt {
-    fn default() -> Self {
-        Interrupt(0)
-    }
-}
 
 /// Struct useful for returning the interrupt status
 /// of the ICM. Provides methods for easy parsing of
@@ -1191,8 +1186,8 @@ impl Icm {
     ///
     /// This field is only reset by `swrst`
     #[inline]
-    pub fn get_urat(&self) -> Variant<u8, URAT_A> {
-        self.uasr().read().urat().variant()
+    pub fn get_urat(&self) -> URAT_A {
+        self.uasr().read().urat().variant().unwrap()
     }
 
     /// When reading the interrupt (ISR) register, it is cleared
@@ -1235,9 +1230,9 @@ pub trait RegionNum: Sealed {
 seq!(N in 0..=3 {
     paste! {
         #[doc = "ICM Region " N]
-        pub enum Region #N {}
-        impl Sealed for Region #N {}
-        impl RegionNum for Region #N {
+        pub enum Region~N {}
+        impl Sealed for Region~N {}
+        impl RegionNum for Region~N {
             const NUM: usize = N;
             #[allow(clippy::identity_op)]
             #[allow(clippy::erasing_op)]
@@ -1338,8 +1333,8 @@ impl MainRegionDesc<Region0> {
 seq!(N in 0..=3 {
     paste! {
         #[doc = "Create region descriptor " N]
-        impl MainRegionDesc<Region #N> {
-            const fn new_region #N() -> Self {
+        impl MainRegionDesc<Region~N> {
+            const fn new_region~N() -> Self {
                 MainRegionDesc {
                     num: PhantomData,
                     raddr: RegionAddress::default(),
